{*******************************************************************************
*  TAllSystemPaths version 0.1                                                 *
********************************************************************************
* Author: Raoul Snyman                                                         *
* ---------------------------------------------------------------------------- *
* E-Mail: components@saturnlaboratories.gq.nu                                  *
* ---------------------------------------------------------------------------- *
* Copyright: 2002 Saturn Laboratories, All rights reserved.                   *
* ---------------------------------------------------------------------------- *
* Description: I've come across so many components with system information,    *
*              some lack in one area, where others lack elsewhere. So having   *
*              got fed up with this, I decided to write a component that would *
*              contain EVERYTHING. Now this contains about 95% of all the sys- *
*              tem paths available (I think). The ones I've left out have been *
*              left out because I didn't think they would be needed.           *
********************************************************************************
* This component is FREEWARE.                                                  *
* ---------------------------------------------------------------------------- *
* Please let me know if you find it useful!!                                   *
* ---------------------------------------------------------------------------- *
* It may be used for commercial purposes on the condition that you give me     *
* credit (i.e. place it in your credits list). Check out my TScrollingCredits. *
* ---------------------------------------------------------------------------- *
* If used in freeware, it's not necessary to give me credit, although it would *
* be appreciated.                                                              *
* ---------------------------------------------------------------------------- *
* If you modify this code, please send me an e-mail with a copy of the code    *
* attached, letting me know what it was that you changed/modified/added.       *
* Use the structure below for including your modification(s). The use the ref- *
* erence at the end of all the lines of code you added or modified. Thanks.    *
********************************************************************************
* Modified: (first name) (last name), Reference: // (initials)                 *
*           (version), (date)                                                  *
*           (description of modification)                                      *
*******************************************************************************}

unit AllSystemPaths;

interface

uses
  Windows, Messages, SysUtils, Classes, Registry;

type
  TAllSystemPaths = class(TComponent)
  private
    { Private declarations }
  protected
    { Protected declarations }
  public
    { Public declarations }
    function GetProgramFilesPath: String;
    function GetProgramFilesDir: String;
    function GetWinDir: String;
    function GetWinBootDir: String;
    function GetBootDir: String;
    function GetCommonFilesDir: String;
    function GetConfigPath: String;
    function GetDevicePath: String;
    function GetMediaPath: String;
    function GetProductID: String;
    function GetProductName: String;
    function GetRegisteredOrganization: String;
    function GetRegisteredOwner: String;
    function GetSystemRoot: String;
    function GetVersion: String;
    function GetVersionNumber: String;
    function GetBootHost: String;
    function GetHostWinBootDir: String;
    function GetMachineDir: String;
    function GetSharedDir: String;
    function GetSysDir: String;
    function GetWallpaper: String;
    function GetWinAdminDir: String;
    function GetAppData: String;
    function GetCache: String;
    function GetCookies: String;
    function GetDesktop: String;
    function GetFavorites: String;
    function GetFonts: String;
    function GetHistory: String;
    function GetMyPictures: String;
    function GetNetHood: String;
    function GetMyDocuments: String;
    function GetStartMenuPrograms: String;
    function GetRecent: String;
    function GetSendTo: String;
    function GetStartMenu: String;
    function GetStartMenuStartup: String;
    procedure Dummy(Value: String);
  published
    { Published declarations }
    property ProgramFilesPath: String read GetProgramFilesPath write Dummy;
    property ProgramFilesDir: String read GetProgramFilesDir write Dummy;
    property WinDir: String read GetWinDir write Dummy;
    property WinBootDir: String read GetWinBootDir write Dummy;
    property BootDir: String read GetBootDir write Dummy;
    property CommonFilesDir: String read GetCommonFilesDir write Dummy;
    property ConfigPath: String read GetConfigPath write Dummy;
    property DevicePath: String read GetDevicePath write Dummy;
    property MediaPath: String read GetMediaPath write Dummy;
    property ProductID: String read GetProductID write Dummy;
    property ProductName: String read GetProductName write Dummy;
    property RegisteredOrganization: String read GetRegisteredOrganization write Dummy;
    property RegisteredOwner: String read GetRegisteredOwner write Dummy;
    property SystemRoot: String read GetSystemRoot write Dummy;
    property Version: String read GetVersion write Dummy;
    property VersionNumber: String read GetVersionNumber write Dummy;
    property BootHost: String read GetBootHost write Dummy;
    property HostWinBootDir: String read GetHostWinBootDir write Dummy;
    property MachineDir: String read GetMachineDir write Dummy;
    property SharedDir: String read GetSharedDir write Dummy;
    property SysDir: String read GetSysDir write Dummy;
    property Wallpaper: String read GetWallpaper write Dummy;
    property WinAdminDir: String read GetWinAdminDir write Dummy;
    property AppData: String read GetAppData write Dummy;
    property Cache: String read GetCache write Dummy;
    property Cookies: String read GetCookies write Dummy;
    property Desktop: String read GetDesktop write Dummy;
    property Favorites: String read GetFavorites write Dummy;
    property Fonts: String read GetFonts write Dummy;
    property History: String read GetHistory write Dummy;
    property MyPictures: String read GetMyPictures write Dummy;
    property NetHood: String read GetNetHood write Dummy;
    property MyDocuments: String read GetMyDocuments write Dummy;
    property StartMenuPrograms: String read GetStartMenuPrograms write Dummy;
    property Recent: String read GetRecent write Dummy;
    property SendTo: String read GetSendTo write Dummy;
    property StartMenu: String read GetStartMenu write Dummy;
    property StartMenuStartup: String read GetStartMenuStartup write Dummy;
  end;

procedure Register;

implementation

var Reg: TRegistry;

procedure TAllSystemPaths.Dummy(Value: String);
begin
 // Dummy procedure...
end;

function TAllSystemPaths.GetProgramFilesPath: String;
begin
 Reg := TRegistry.Create;
 Reg.RootKey := HKEY_LOCAL_MACHINE;
 Reg.OpenKey('Software\Microsoft\Windows\CurrentVersion', False);
 GetProgramFilesPath := Reg.ReadString('ProgramFilesPath');
 Reg.Free;
end;

function TAllSystemPaths.GetProgramFilesDir: String;
begin
 Reg := TRegistry.Create;
 Reg.RootKey := HKEY_LOCAL_MACHINE;
 Reg.OpenKey('Software\Microsoft\Windows\CurrentVersion', False);
 GetProgramFilesDir := Reg.ReadString('ProgramFilesDir');
 Reg.Free;
end;

function TAllSystemPaths.GetWinDir: String;
begin
 Reg := TRegistry.Create;
 Reg.RootKey := HKEY_LOCAL_MACHINE;
 Reg.OpenKey('Software\Microsoft\Windows\CurrentVersion\Setup', False);
 GetWinDir := Reg.ReadString('WinDir');
 Reg.Free;
end;

function TAllSystemPaths.GetWinBootDir: String;
begin
 Reg := TRegistry.Create;
 Reg.RootKey := HKEY_LOCAL_MACHINE;
 Reg.OpenKey('Software\Microsoft\Windows\CurrentVersion\Setup', False);
 GetWinBootDir := Reg.ReadString('WinBootDir');
 Reg.Free;
end;

function TAllSystemPaths.GetBootDir: String;
begin
 Reg := TRegistry.Create;
 Reg.RootKey := HKEY_LOCAL_MACHINE;
 Reg.OpenKey('Software\Microsoft\Windows\CurrentVersion\Setup', False);
 GetBootDir := Reg.ReadString('BootDir');
 Reg.Free;
end;

function TAllSystemPaths.GetCommonFilesDir: String;
begin
 Reg := TRegistry.Create;
 Reg.RootKey := HKEY_LOCAL_MACHINE;
 Reg.OpenKey('Software\Microsoft\Windows\CurrentVersion', False);
 GetCommonFilesDir := Reg.ReadString('CommonFilesDir');
 Reg.Free;
end;

function TAllSystemPaths.GetConfigPath: String;
begin
 Reg := TRegistry.Create;
 Reg.RootKey := HKEY_LOCAL_MACHINE;
 Reg.OpenKey('Software\Microsoft\Windows\CurrentVersion', False);
 GetConfigPath := Reg.ReadString('ConfigPath');
 Reg.Free;
end;

function TAllSystemPaths.GetDevicePath: String;
begin
 Reg := TRegistry.Create;
 Reg.RootKey := HKEY_LOCAL_MACHINE;
 Reg.OpenKey('Software\Microsoft\Windows\CurrentVersion', False);
 GetDevicePath := Reg.ReadString('DevicePath');
 Reg.Free;
end;

function TAllSystemPaths.GetMediaPath: String;
begin
 Reg := TRegistry.Create;
 Reg.RootKey := HKEY_LOCAL_MACHINE;
 Reg.OpenKey('Software\Microsoft\Windows\CurrentVersion', False);
 GetMediaPath := Reg.ReadString('MediaPath');
 Reg.Free;
end;

function TAllSystemPaths.GetProductID: String;
begin
 Reg := TRegistry.Create;
 Reg.RootKey := HKEY_LOCAL_MACHINE;
 Reg.OpenKey('Software\Microsoft\Windows\CurrentVersion', False);
 GetProductID := Reg.ReadString('ProductID');
 Reg.Free;
end;

function TAllSystemPaths.GetProductName: String;
begin
 Reg := TRegistry.Create;
 Reg.RootKey := HKEY_LOCAL_MACHINE;
 Reg.OpenKey('Software\Microsoft\Windows\CurrentVersion', False);
 GetProductName := Reg.ReadString('ProductName');
 Reg.Free;
end;

function TAllSystemPaths.GetRegisteredOrganization: String;
begin
 Reg := TRegistry.Create;
 Reg.RootKey := HKEY_LOCAL_MACHINE;
 Reg.OpenKey('Software\Microsoft\Windows\CurrentVersion', False);
 GetRegisteredOrganization := Reg.ReadString('RegisteredOrganization');
 Reg.Free;
end;

function TAllSystemPaths.GetRegisteredOwner: String;
begin
 Reg := TRegistry.Create;
 Reg.RootKey := HKEY_LOCAL_MACHINE;
 Reg.OpenKey('Software\Microsoft\Windows\CurrentVersion', False);
 GetRegisteredOwner := Reg.ReadString('RegisteredOwner');
 Reg.Free;
end;

function TAllSystemPaths.GetSystemRoot: String;
begin
 Reg := TRegistry.Create;
 Reg.RootKey := HKEY_LOCAL_MACHINE;
 Reg.OpenKey('Software\Microsoft\Windows\CurrentVersion', False);
 GetSystemRoot := Reg.ReadString('SystemRoot');
 Reg.Free;
end;

function TAllSystemPaths.GetVersion: String;
begin
 Reg := TRegistry.Create;
 Reg.RootKey := HKEY_LOCAL_MACHINE;
 Reg.OpenKey('Software\Microsoft\Windows\CurrentVersion', False);
 GetVersion := Reg.ReadString('Version');
 Reg.Free;
end;

function TAllSystemPaths.GetVersionNumber: String;
begin
 Reg := TRegistry.Create;
 Reg.RootKey := HKEY_LOCAL_MACHINE;
 Reg.OpenKey('Software\Microsoft\Windows\CurrentVersion', False);
 GetVersionNumber := Reg.ReadString('VersionNumber');
 Reg.Free;
end;

function TAllSystemPaths.GetBootHost: String;
begin
 Reg := TRegistry.Create;
 Reg.RootKey := HKEY_LOCAL_MACHINE;
 Reg.OpenKey('Software\Microsoft\Windows\CurrentVersion\Setup', False);
 GetBootHost := Reg.ReadString('BootHost');
 Reg.Free;
end;

function TAllSystemPaths.GetHostWinBootDir: String;
begin
 Reg := TRegistry.Create;
 Reg.RootKey := HKEY_LOCAL_MACHINE;
 Reg.OpenKey('Software\Microsoft\Windows\CurrentVersion\Setup', False);
 GetHostWinBootDir := Reg.ReadString('HostWinBootDir');
 Reg.Free;
end;

function TAllSystemPaths.GetMachineDir: String;
begin
 Reg := TRegistry.Create;
 Reg.RootKey := HKEY_LOCAL_MACHINE;
 Reg.OpenKey('Software\Microsoft\Windows\CurrentVersion\Setup', False);
 GetMachineDir := Reg.ReadString('MachineDir');
 Reg.Free;
end;

function TAllSystemPaths.GetSharedDir: String;
begin
 Reg := TRegistry.Create;
 Reg.RootKey := HKEY_LOCAL_MACHINE;
 Reg.OpenKey('Software\Microsoft\Windows\CurrentVersion\Setup', False);
 GetSharedDir := Reg.ReadString('SharedDir');
 Reg.Free;
end;

function TAllSystemPaths.GetSysDir: String;
begin
 Reg := TRegistry.Create;
 Reg.RootKey := HKEY_LOCAL_MACHINE;
 Reg.OpenKey('Software\Microsoft\Windows\CurrentVersion\Setup', False);
 GetSysDir := Reg.ReadString('SysDir');
 Reg.Free;
end;

function TAllSystemPaths.GetWallpaper: String;
begin
 Reg := TRegistry.Create;
 Reg.RootKey := HKEY_LOCAL_MACHINE;
 Reg.OpenKey('Software\Microsoft\Windows\CurrentVersion\Setup', False);
 GetWallpaper := Reg.ReadString('Wallpaper');
 Reg.Free;
end;

function TAllSystemPaths.GetWinAdminDir: String;
begin
 Reg := TRegistry.Create;
 Reg.RootKey := HKEY_LOCAL_MACHINE;
 Reg.OpenKey('Software\Microsoft\Windows\CurrentVersion\Setup', False);
 GetWinAdminDir := Reg.ReadString('WinAdminDir');
 Reg.Free;
end;

function TAllSystemPaths.GetAppData: String;
begin
 Reg := TRegistry.Create;
 Reg.RootKey := HKEY_CURRENT_USER;
 Reg.OpenKey('Software\Microsoft\Windows\CurrentVersion\Explorer\Shell Folders', False);
 GetAppData := Reg.ReadString('AppData');
 Reg.Free;
end;

function TAllSystemPaths.GetCache: String;
begin
 Reg := TRegistry.Create;
 Reg.RootKey := HKEY_CURRENT_USER;
 Reg.OpenKey('Software\Microsoft\Windows\CurrentVersion\Explorer\Shell Folders', False);
 GetCache := Reg.ReadString('Cache');
 Reg.Free;
end;

function TAllSystemPaths.GetCookies: String;
begin
 Reg := TRegistry.Create;
 Reg.RootKey := HKEY_CURRENT_USER;
 Reg.OpenKey('Software\Microsoft\Windows\CurrentVersion\Explorer\Shell Folders', False);
 GetCookies := Reg.ReadString('Cookies');
 Reg.Free;
end;

function TAllSystemPaths.GetDesktop: String;
begin
 Reg := TRegistry.Create;
 Reg.RootKey := HKEY_CURRENT_USER;
 Reg.OpenKey('Software\Microsoft\Windows\CurrentVersion\Explorer\Shell Folders', False);
 GetDesktop := Reg.ReadString('Desktop');
 Reg.Free;
end;

function TAllSystemPaths.GetFavorites: String;
begin
 Reg := TRegistry.Create;
 Reg.RootKey := HKEY_CURRENT_USER;
 Reg.OpenKey('Software\Microsoft\Windows\CurrentVersion\Explorer\Shell Folders', False);
 GetFavorites := Reg.ReadString('Favorites');
 Reg.Free;
end;

function TAllSystemPaths.GetFonts: String;
begin
 Reg := TRegistry.Create;
 Reg.RootKey := HKEY_CURRENT_USER;
 Reg.OpenKey('Software\Microsoft\Windows\CurrentVersion\Explorer\Shell Folders', False);
 GetFonts := Reg.ReadString('Fonts');
 Reg.Free;
end;

function TAllSystemPaths.GetHistory: String;
begin
 Reg := TRegistry.Create;
 Reg.RootKey := HKEY_CURRENT_USER;
 Reg.OpenKey('Software\Microsoft\Windows\CurrentVersion\Explorer\Shell Folders', False);
 GetHistory := Reg.ReadString('History');
 Reg.Free;
end;

function TAllSystemPaths.GetMyPictures: String;
begin
 Reg := TRegistry.Create;
 Reg.RootKey := HKEY_CURRENT_USER;
 Reg.OpenKey('Software\Microsoft\Windows\CurrentVersion\Explorer\Shell Folders', False);
 GetMyPictures := Reg.ReadString('My Pictures');
 Reg.Free;
end;

function TAllSystemPaths.GetNetHood: String;
begin
 Reg := TRegistry.Create;
 Reg.RootKey := HKEY_CURRENT_USER;
 Reg.OpenKey('Software\Microsoft\Windows\CurrentVersion\Explorer\Shell Folders', False);
 GetNetHood := Reg.ReadString('NetHood');
 Reg.Free;
end;

function TAllSystemPaths.GetMyDocuments: String;
begin
 Reg := TRegistry.Create;
 Reg.RootKey := HKEY_CURRENT_USER;
 Reg.OpenKey('Software\Microsoft\Windows\CurrentVersion\Explorer\Shell Folders', False);
 GetMyDocuments := Reg.ReadString('Personal');
 Reg.Free;
end;

function TAllSystemPaths.GetStartMenuPrograms: String;
begin
 Reg := TRegistry.Create;
 Reg.RootKey := HKEY_CURRENT_USER;
 Reg.OpenKey('Software\Microsoft\Windows\CurrentVersion\Explorer\Shell Folders', False);
 GetStartMenuPrograms := Reg.ReadString('Programs');
 Reg.Free;
end;

function TAllSystemPaths.GetRecent: String;
begin
 Reg := TRegistry.Create;
 Reg.RootKey := HKEY_CURRENT_USER;
 Reg.OpenKey('Software\Microsoft\Windows\CurrentVersion\Explorer\Shell Folders', False);
 GetRecent := Reg.ReadString('Recent');
 Reg.Free;
end;

function TAllSystemPaths.GetSendTo: String;
begin
 Reg := TRegistry.Create;
 Reg.RootKey := HKEY_CURRENT_USER;
 Reg.OpenKey('Software\Microsoft\Windows\CurrentVersion\Explorer\Shell Folders', False);
 GetSendTo := Reg.ReadString('SendTo');
 Reg.Free;
end;

function TAllSystemPaths.GetStartMenu: String;
begin
 Reg := TRegistry.Create;
 Reg.RootKey := HKEY_CURRENT_USER;
 Reg.OpenKey('Software\Microsoft\Windows\CurrentVersion\Explorer\Shell Folders', False);
 GetStartMenu := Reg.ReadString('Start Menu');
 Reg.Free;
end;

function TAllSystemPaths.GetStartMenuStartup: String;
begin
 Reg := TRegistry.Create;
 Reg.RootKey := HKEY_CURRENT_USER;
 Reg.OpenKey('Software\Microsoft\Windows\CurrentVersion\Explorer\Shell Folders', False);
 GetStartMenuStartup := Reg.ReadString('Startup');
 Reg.Free;
end;


procedure Register;
begin
  RegisterComponents('Samples', [TAllSystemPaths]);
end;

end.
